@@ -1,5 +1,5 @@
 /**
- * headphoned for the Nokia N8x0
+ * headphoned for the Nokia N8x0 and the N900
  *
  * The headphone daemon watches the state of the headphone
  * plug (connected, disconnected) and carries out actions
@@ -9,7 +9,23 @@
  *   * Send "pause" to the media player on disconnect
  *   * Maintain different volume settings for each state
  *
- * Copyright (c) 2009-10-21 Thomas Perl <thpinfo.com>
+ * Initial working version: 2009-10-21
+ *
+ * Copyright (c) 2009-2010 Thomas Perl <thpinfo.com>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this package; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
  **/
 
 #include <stdio.h>
@@ -19,7 +35,8 @@
 #include <libosso.h>
 #include <dbus/dbus.h>
 #include <fcntl.h>
-#include <unistd.h>
+
+#include "config.h"
 
 #define STATE_FILE "/sys/devices/platform/gpio-switch/headphone/state"
 #define STATE_CONNECTED_STR "connected"
@@ -27,9 +44,15 @@
 
 #define GCONF_VOLUME_CONTROL "/apps/osso/sound/master_volume"
 
-#define MEDIA_SERVER_SRVC "com.nokia.osso_media_server"
-#define MEDIA_SERVER_PATH "/com/nokia/osso_media_server"
-#define MEDIA_SERVER_INTF "com.nokia.osso_media_server.music"
+#ifdef DIABLO
+#    define MEDIA_SERVER_SRVC "com.nokia.osso_media_server"
+#    define MEDIA_SERVER_PATH "/com/nokia/osso_media_server"
+#    define MEDIA_SERVER_INTF "com.nokia.osso_media_server.music"
+#else
+#    define MEDIA_SERVER_SRVC "com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer"
+#    define MEDIA_SERVER_PATH "/com/nokia/mafw/renderer/gstrenderer"
+#    define MEDIA_SERVER_INTF "com.nokia.mafw.renderer"
+#endif
 
 #define PANUCCI_SRVC "org.panucci.panucciInterface"
 #define PANUCCI_PATH "/panucciInterface"
@@ -37,12 +60,6 @@
 
 #define MPLAYER_FIFO "/etc/headphoned/mplayer-input"
 
-// Volume control is currently broken, as something is messing
-// with the controls from outside this process in GConf..
-//#define ENABLE_VOLUME_CONTROL
-#define ENABLE_PAUSE_ON_DISCONNECT
-
-
 enum { STATE_UNKNOWN, STATE_CONNECTED, STATE_DISCONNECTED, STATE_COUNT };
 
 typedef struct {
@@ -95,8 +112,6 @@ on_file_changed(GIOChannel* source, GIOCondition condition, gpointer data)
 #endif
 	gchar* result;
 	int mplayer_fifo;
-	GError *error;
-	static gchar *mpd_pause[] = {"mpc", "pause", NULL};
 
 	g_io_channel_seek_position(source, 0, G_SEEK_SET, NULL);
 	g_io_channel_read_line(source, &result, NULL, NULL, NULL);
@@ -136,21 +151,6 @@ on_file_changed(GIOChannel* source, GIOCondition condition, gpointer data)
 				write(mplayer_fifo, "pause\n", 6);
 				close(mplayer_fifo);
 			}
-
-			/* mpd via mpc */
-			if (!g_spawn_async(NULL,
-				           mpd_pause,
-					   NULL,
-					   G_SPAWN_SEARCH_PATH |
-					   G_SPAWN_STDOUT_TO_DEV_NULL |
-					   G_SPAWN_STDERR_TO_DEV_NULL,
-					   NULL,
-					   NULL,
-					   NULL,
-					   &error)) {
-				/* If we arrive here, mpc is not installed */
-				g_error_free(error);
-			}
 		}
 #endif
 	}
